# Universal Parser

## _Json, Pickle, Toml, Yaml parser_

This is a 4-in-1 encoder and decoder. Fully compatible with default parsers.
There is a full support for primitives, for functions and classes.
Can be used in programs and in console.
